/*
Summary:
	Type specific tests for saAmfComponentErrorClear

Description:
	Calls saAmfComponentErrorClear with all the combinations of the values returned by the type-specific generators

Version history:
	Generated by typeSpecificTestTemplate.xsl
*/

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <unistd.h>
#include <errno.h>

#include "saAis.h"
#include "saAmf.h"
#include "saClm.h"

#include "testCommon.h"
#include "generateTypes.h"


/* Calls the AIS function for each possible combinations of the parameter values.
Starts a new process with fork for each test call. */
int main(){
  FILE * logFile;		    // log file for results

  srand( 5 );             	// do not use a changing seed (like time()), because the tests need to be repeatable
  SaAisErrorT result; 		// return value
  int pid, status;	    	// used for fork
  int numberOfCalls = 0;
  
  // loop variables
  
    int loop1;
  
    int loop2;
  
    int loop3;
  
  
  // wait for the middleware to start the component
  fprintf(stderr, "LOG>waiting before calls\n");
  sleep(WAIT_BEFORE_START);
  fprintf(stderr, "LOG>starting calls\n");

  
  // Parameter value domain
  
    int p1Number;    // number of generated parameters
    SaAmfHandleT* param1s = generateSaAmfHandleT(&p1Number);
    
    int p2Number;    // number of generated parameters
    SaNameT** param2s = generatePointerSaNameT(&p2Number);
    
    int p3Number;    // number of generated parameters
    SaNtfIdentifierT* param3s = generateSaNtfIdentifierT(&p3Number);
    

  // open log file
  openLogFile( &logFile, "saAmfComponentErrorClear", WRITE_HEADER );
  
  // write log file header
  if ( WRITE_HEADER )
  {
	fprintf(logFile, "functionName;");
	 
		fprintf(logFile, "amfHandle,");
	 
		fprintf(logFile, "compName,");
	 
		fprintf(logFile, "ntfIdentifier");
	 
	fprintf(logFile, ";saErrorT;processStatusCode\n");	
	fflush( logFile );
  }

  
  
    for (loop1 = 0; loop1 < p1Number; loop1++ ){
  
    for (loop2 = 0; loop2 < p2Number; loop2++ ){
  
    for (loop3 = 0; loop3 < p3Number; loop3++ ){
  
  
  // stop, if limit is reached
  //TODO: use random parameter selecting instead of calling only the first MAX_NUMBER_OF_CALLS
  numberOfCalls++;
  if ( numberOfCalls == MAX_NUMBER_OF_CALLS )
  {
    printf("call limit reached in saAmfComponentErrorClear!\n");
	goto freeAndExit;
  }
  
  // create a new child process
  if ((pid = fork()) < 0){
    perror("fork");
    exit(1);
  }

  if ( pid == 0 ) // child process
  {
    // set timeout for the test
    alarm( TEST_TIMEOUT );

    
    // set params
    SaAmfHandleT param1 = param1s[loop1];
    SaNameT* param2 = param2s[loop2];
    SaNtfIdentifierT param3 = param3s[loop3];
    

    // call one AIS function with random values
    fprintf( logFile, "saAmfComponentErrorClear;" ); fflush( logFile );
    fprintf( logFile, "%s,%s,%s", 
		    SaAmfHandleToString(&param1)
          ,SaNameToString(param2)
          ,SaNtfIdentifierToString(&param3)
          );
    fflush( logFile );

    result = saAmfComponentErrorClear(
    
      param1,
      param2,
      param3
    );

    fprintf(logFile, ";%s", SaAisErrorToString(&result));
    fflush( logFile );
    exit(0);
  } // end child process

  // parent process, wait for child to complete
  while ( wait(&status) != pid){
  }

  // if the test produced a segmentation fault, then it did not write out the saError result, so write out a blank value
  if ( status == 11 /* segmentation fault */ || status == 14 /* SIGALARM */ )
    fprintf( logFile, ";" );

  fprintf( logFile, ";%d\n", status );
  fflush( logFile );

  
  
    } // for
  
    } // for
  
    } // for
  

  freeAndExit:
  // free resources
  
      free(param2s);      
    
  fclose( logFile );
  
  fprintf(stderr, "LOG>finished calls\n");
  
  // mark finish in external file
  // reason: the test program is run by the AMF as a component, thus we dont now, when has it finished the calls
  FILE * finishedFile;
  finishedFile = fopen(FINISHED_FILE_NAME, "w");
  fprintf( finishedFile, "saAmfComponentErrorClear finished" );
  fclose( finishedFile );
  
  return 0;
} // main


    
